@@ -55,6 +55,12 @@
 #define PLACEMENT_MOUSE                 0
 #define PLACEMENT_ROOT                  1
 
+#define CFG_NONE                        0
+#define CFG_CONSTRAINED                 (1<<0)
+#define CFG_REQUEST                     (1<<1)
+#define CFG_NOTIFY                      (1<<2)
+#define CFG_FORCE_REDRAW                (1<<3)
+
 #define INCLUDE_HIDDEN                  (1<<0)
 #define INCLUDE_SKIP_FOCUS              (1<<1)
 #define INCLUDE_ALL_WORKSPACES          (1<<2)
@@ -73,7 +79,7 @@
 #define MARGIN_TOP                      2
 #define MARGIN_BOTTOM                   3
 
-#define CLIENT_MIN_VISIBLE              10	/* pixels */
+#define CLIENT_MIN_VISIBLE              10      /* pixels */
 
 #define CLIENT_FLAG_FOCUS              (1L<<0)
 #define CLIENT_FLAG_ABOVE              (1L<<1)
@@ -87,27 +93,27 @@
 #define CLIENT_FLAG_HAS_MOVE           (1L<<9)
 #define CLIENT_FLAG_HAS_RESIZE         (1L<<10)
 #define CLIENT_FLAG_HAS_STICK          (1L<<11)
-#define CLIENT_FLAG_IS_RESIZABLE       (1L<<12)
-#define CLIENT_FLAG_HAS_STRUTS         (1L<<13)
-#define CLIENT_FLAG_HIDDEN             (1L<<14)
-#define CLIENT_FLAG_MANAGED            (1L<<15)
-#define CLIENT_FLAG_MAXIMIZED_VERT     (1L<<16)
-#define CLIENT_FLAG_MAXIMIZED_HORIZ    (1L<<17)
+#define CLIENT_FLAG_HAS_STRUTS         (1L<<12)
+#define CLIENT_FLAG_IS_RESIZABLE       (1L<<13)
+#define CLIENT_FLAG_MAP_PENDING        (1L<<14)
+#define CLIENT_FLAG_VISIBLE            (1L<<15)
+#define CLIENT_FLAG_HIDDEN             (1L<<16)
+#define CLIENT_FLAG_MANAGED            (1L<<17)
+#define CLIENT_FLAG_MAXIMIZED_VERT     (1L<<18)
+#define CLIENT_FLAG_MAXIMIZED_HORIZ    (1L<<19)
 #define CLIENT_FLAG_MAXIMIZED          (CLIENT_FLAG_MAXIMIZED_VERT | CLIENT_FLAG_MAXIMIZED_HORIZ)
-#define CLIENT_FLAG_SHADED             (1L<<18)
-#define CLIENT_FLAG_SKIP_PAGER         (1L<<19)
-#define CLIENT_FLAG_SKIP_TASKBAR       (1L<<20)
-#define CLIENT_FLAG_STATE_MODAL        (1L<<21)
-#define CLIENT_FLAG_STICKY             (1L<<22)
-#define CLIENT_FLAG_VISIBLE            (1L<<23)
-#define CLIENT_FLAG_WM_DELETE          (1L<<24)
-#define CLIENT_FLAG_WM_INPUT           (1L<<25)
-#define CLIENT_FLAG_WM_TAKEFOCUS       (1L<<26)
-#define CLIENT_FLAG_MOVING_RESIZING    (1L<<27)
-#define CLIENT_FLAG_NAME_CHANGED       (1L<<28)
-#define CLIENT_FLAG_SESSION_MANAGED    (1L<<29)
-#define CLIENT_FLAG_WORKSPACE_SET      (1L<<30)
-#define CLIENT_FLAG_REPARENTING        (1L<<31)
+#define CLIENT_FLAG_SHADED             (1L<<20)
+#define CLIENT_FLAG_SKIP_PAGER         (1L<<21)
+#define CLIENT_FLAG_SKIP_TASKBAR       (1L<<22)
+#define CLIENT_FLAG_STATE_MODAL        (1L<<23)
+#define CLIENT_FLAG_STICKY             (1L<<24)
+#define CLIENT_FLAG_WM_DELETE          (1L<<25)
+#define CLIENT_FLAG_WM_INPUT           (1L<<26)
+#define CLIENT_FLAG_WM_TAKEFOCUS       (1L<<27)
+#define CLIENT_FLAG_MOVING_RESIZING    (1L<<28)
+#define CLIENT_FLAG_NAME_CHANGED       (1L<<29)
+#define CLIENT_FLAG_SESSION_MANAGED    (1L<<30)
+#define CLIENT_FLAG_WORKSPACE_SET      (1L<<31)
 
 #define CLIENT_FLAG_INITIAL_VALUES     CLIENT_FLAG_HAS_BORDER | \
                                        CLIENT_FLAG_HAS_MENU | \
@@ -185,6 +191,7 @@ struct _Client
     WindowType type;
     gboolean draw_active;
     gboolean first_map;
+    gboolean legacy_fullscreen;
     int x;
     int y;
     int width;
@@ -220,21 +227,28 @@ extern Client *clients;
 extern Window *client_list;
 extern unsigned int client_count;
 
-Client *clientGetTransient (Client *);
-gboolean clientIsTransient (Client *);
-gboolean clientSameGroup (Client *, Client *);
-gboolean clientIsTransientFor (Client *, Client *);
-gboolean clientIsTransientForGroup (Client *);
-gboolean clientTransientHasAncestor (Client *, int);
+inline Client *clientGetTransient (Client *);
+inline gboolean clientIsTransient (Client *);
+inline gboolean clientIsModal (Client *);
+inline gboolean clientIsTransientOrModal (Client *);
+inline gboolean clientSameGroup (Client *, Client *);
+inline gboolean clientIsTransientFor (Client *, Client *);
+inline gboolean clientIsModalFor (Client *, Client *);
+inline gboolean clientIsTransientOrModalFor (Client *, Client *);
+inline gboolean clientIsTransientForGroup (Client *);
+inline gboolean clientIsModalForGroup (Client *);
+inline gboolean clientIsTransientOrModalForGroup (Client *);
 void clientSetNetState (Client *);
 void clientUpdateWinState (Client *, XClientMessageEvent *);
 void clientUpdateNetState (Client *, XClientMessageEvent *);
 void clientGetNetWmType (Client * c);
 void clientCoordGravitate (Client *, int, int *, int *);
 void clientGravitate (Client *, int);
-void clientConfigure (Client *, XWindowChanges *, int, gboolean, gboolean);
+void clientConfigure (Client *, XWindowChanges *, int, unsigned short);
 void clientGetMWMHints (Client *, gboolean);
 void clientGetWMNormalHints (Client *, gboolean);
+void clientGetWMProtocols (Client *);
+void clientFocusNew(Client *);
 void clientClearPixmapCache (Client *);
 void clientFrame (Window, gboolean);
 void clientUnframe (Client *, gboolean);
@@ -269,7 +283,7 @@ inline void clientRemoveMaximizeFlag (Client *);
 void clientToggleMaximized (Client *, int);
 void clientUpdateFocus (Client *);
 inline gboolean clientAcceptFocus (Client * c);
-void clientSetFocus (Client *, gboolean);
+void clientSetFocus (Client *, gboolean, gboolean);
 Client *clientGetFocus ();
 void clientScreenResize(void);
 void clientMove (Client *, XEvent *);
@@ -277,7 +291,7 @@ void clientResize (Client *, int, XEvent *);
 void clientCycle (Client *);
 void clientButtonPress (Client *, Window, XButtonEvent *);
 Client *clientGetLeader (Client *);
-GSList *clientGetStackList (void);
+GList *clientGetStackList (void);
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
 char *clientGetStartupId (Client *);
 #endif
